@@ -106,6 +106,7 @@ from neutron_lib.api.definitions import portbindings_extended
 from neutron_lib.api.definitions import project_default_networks
 from neutron_lib.api.definitions import project_id
 from neutron_lib.api.definitions import provider_net
+from neutron_lib.api.definitions import qinq
 from neutron_lib.api.definitions import qos
 from neutron_lib.api.definitions import qos_bw_limit_direction
 from neutron_lib.api.definitions import qos_bw_minimum_ingress
@@ -268,6 +269,7 @@ _ALL_API_DEFINITIONS = {
     project_default_networks,
     project_id,
     provider_net,
+    qinq,
     qos,
     qos_bw_limit_direction,
     qos_bw_minimum_ingress,
